@@ -171,6 +171,7 @@
     (python-ts-mode         . ,(treesit-fold-parsers-python))
     (qss-mode               . ,(treesit-fold-parsers-qss))
     (rjsx-mode              . ,(treesit-fold-parsers-javascript))
+    (ron-mode               . ,(treesit-fold-parsers-ron))
     (rst-mode               . ,(treesit-fold-parsers-rst))
     (ruby-mode              . ,(treesit-fold-parsers-ruby))
     (ruby-ts-mode           . ,(treesit-fold-parsers-ruby))
@@ -191,7 +192,7 @@
     (tuareg-mode            . ,(treesit-fold-parsers-ocaml))
     (typescript-mode        . ,(treesit-fold-parsers-typescript))
     (typescript-ts-mode     . ,(treesit-fold-parsers-typescript))
-    (tsx-ts-mode            . ,(treesit-fold-parsers-typescript))
+    (tsx-ts-mode            . ,(treesit-fold-parsers-tsx))
     (verilog-mode           . ,(treesit-fold-parsers-verilog))
     (verilog-ts-mode        . ,(treesit-fold-parsers-verilog))
     (vhdl-mode              . ,(treesit-fold-parsers-vhdl))
